# TODO

## Completed
- [x] Renamed package from `botibot` to `modules`
- [x] Integrated gpiozero library for GPIO control
- [x] Updated all imports to use `modules` package
- [x] Removed TFT references from configuration
- [x] Updated CLI commands to use `modules-*` prefix

## Upcoming Features
- [ ] Add GSM module implementation (SIM800L)
- [ ] Add IR temperature sensor support (GY-906)
- [ ] Add auto-navigation module
- [ ] Add scheduler module functionality
- [ ] Improve error handling and logging
- [ ] Add more sensor calibration options
- [ ] Implement advanced motor control patterns